@@ -18,7 +18,7 @@ import traceback
 from os.path import basename, normpath
 from typing import Any, Collection, Iterable, List, Optional, Set, Union
 
-from mitosheet.types import ColumnHeader, ColumnID, StateType
+from mitosheet.types import ColumnHeader, ColumnID, Operator, StateType
 
 
 class MitoError(Exception):
@@ -507,16 +507,29 @@ def make_invalid_simple_import_error(error_modal: bool=False) -> MitoError:
         error_modal=error_modal
     )
 
-def make_invalid_snowflake_import_error() -> MitoError:
+def make_invalid_snowflake_import_error(exception: Exception) -> MitoError:
     """
     Helper function for creating an invalid_snowflake_import_error.
 
-    Occures when the user tries to simple import and it fails.
+    Occures when the user tries to snowflake import and it fails.
     """
     return MitoError(
         'invalid_snowflake_import_error',
         'Cannot Query Database',
-        'We were unable to execute that query. Reach out to support for help.',
+        f'{exception}',
+        False
+    )
+
+def make_invalid_snowflake_credentials_error() -> MitoError:
+    """
+    Helper function for creating an invalid_snowflake_credentials_error.
+
+    Occures when the user tries to snowflake imports, but their credentials are invalid.
+    """
+    return MitoError(
+        'invalid_snowflake_credentials_error',
+        'Invalid Snowflake Credentials',
+        'Your Snowflake connection credentials are invalid. Please enter valid Snowflake credentials and try again.',
         False
     )
 
